from celery import Celery, task
from os import getenv
import logging

from azure.common.credentials import ServicePrincipalCredentials

import azure.mgmt.network

DHCP_LOGFILE = getenv('DHCP_LOGFILE', '/var/log/syslog')

AMQP_URI = getenv('AMQP_URI')

SUBSCRIPTION_ID = getenv('SUBSCRIPTION_ID')
CLIENT_ID = getenv('CLIENT_ID')
SECRET = getenv('SECRET')
TENANT = getenv('TENANT')
GROUP_NAME = getenv('GROUP_NAME')
REGION = getenv('REGION')

subscription_id = SUBSCRIPTION_ID
credentials = ServicePrincipalCredentials(
    client_id = CLIENT_ID,
    secret = SECRET,
    tenant = TENANT,
)

network_client = azure.mgmt.network.NetworkManagementClient(
    credentials,
    subscription_id
)

celery = Celery('fw',)
celery.conf.update(
    BROKER_URL=AMQP_URI,
    CELERY_RESULT_BACKEND='amqp',
    CELERY_TASK_RESULT_EXPIRES=300,
)

logger = logging.getLogger(__name__)

@task(name="firewall.create_network")
def create_network(name, address_prefix):
    logger.info("creating network: %s" % name)
    # virtual network
    poller = network_client.virtual_networks.create_or_update(
        GROUP_NAME,
        name,
        azure.mgmt.network.models.VirtualNetwork(
            location=REGION,
            address_space=azure.mgmt.network.models.AddressSpace(
                address_prefixes=[
                    address_prefix,
                ],
            ),
            subnets=[
                azure.mgmt.network.models.Subnet(
                    name="%s.subnet" % name,
                    address_prefix=address_prefix,
                ),
            ],
        ),
    )
    try:
        poller.wait()
        logger.info("created network: %s" % name)
        return poller.result().id
    except Exception, e:
        logger.error("cloud not create network: %s" % name)
        logger.error(str(e))
        return None